@@ -30,26 +30,32 @@ RcppHoney::traits::true_type is_hooked(const std::set< T, C, A > &val);
 
 // hooks for Rcpp::VectorBase
 template< int RTYPE, bool NA, typename T >
-RcppHoney::traits::true_type is_hooked(const Rcpp::VectorBase< RTYPE, NA, T > &val);
+RcppHoney::traits::true_type is_hooked(
+    const Rcpp::VectorBase< RTYPE, NA, T > &val);
 
 // return the appropriate NA value
 template< int RTYPE, typename T >
-RcppHoney::traits::false_type has_na(const Rcpp::VectorBase< RTYPE, false, T > &val);
+RcppHoney::traits::false_type has_na(
+    const Rcpp::VectorBase< RTYPE, false, T > &val);
 
 template< int RTYPE, typename T >
-RcppHoney::traits::true_type has_na(const Rcpp::VectorBase< RTYPE, true, T > &val);
+RcppHoney::traits::true_type has_na(
+    const Rcpp::VectorBase< RTYPE, true, T > &val);
 
 // assert that we need to create basic operators
 template< int RTYPE, bool NA, typename T >
-RcppHoney::traits::true_type needs_basic_operators(const Rcpp::VectorBase< RTYPE, NA, T > &val);
+RcppHoney::traits::true_type needs_basic_operators(
+    const Rcpp::VectorBase< RTYPE, NA, T > &val);
 
 // assert that we need to create type + scalar operators
 template< int RTYPE, bool NA, typename T >
-RcppHoney::traits::true_type needs_scalar_operators(const Rcpp::VectorBase< RTYPE, NA, T > &val);
+RcppHoney::traits::true_type needs_scalar_operators(
+    const Rcpp::VectorBase< RTYPE, NA, T > &val);
 
 // call this family 2
 template< int RTYPE, bool NA, typename T >
-RcppHoney::traits::int_constant< 2 > family(const Rcpp::VectorBase< RTYPE, NA, T > &val);
+RcppHoney::traits::int_constant< 2 > family(
+    const Rcpp::VectorBase< RTYPE, NA, T > &val);
 
 
 
@@ -59,23 +65,28 @@ RcppHoney::traits::int_constant< 2 > family(const Rcpp::VectorBase< RTYPE, NA, T
 
 // hooks for Rcpp::VectorBase
 template< int RTYPE, template< class > class StoragePolicy >
-RcppHoney::traits::true_type is_hooked(const Rcpp::Matrix< RTYPE, StoragePolicy > &val);
+RcppHoney::traits::true_type is_hooked(
+    const Rcpp::Matrix< RTYPE, StoragePolicy > &val);
 
 // return the appropriate NA value
 template< int RTYPE, template< class > class StoragePolicy >
-RcppHoney::traits::true_type has_na(const Rcpp::Matrix< RTYPE, StoragePolicy > &val);
+RcppHoney::traits::true_type has_na(
+    const Rcpp::Matrix< RTYPE, StoragePolicy > &val);
 
 // assert that we need to create basic operators
 template< int RTYPE, template< class > class StoragePolicy >
-RcppHoney::traits::true_type needs_basic_operators(const Rcpp::Matrix< RTYPE, StoragePolicy > &val);
+RcppHoney::traits::true_type needs_basic_operators(
+    const Rcpp::Matrix< RTYPE, StoragePolicy > &val);
 
 // assert that we need to create type + scalar operators
 template< int RTYPE, template< class > class StoragePolicy >
-RcppHoney::traits::true_type needs_scalar_operators(const Rcpp::Matrix< RTYPE, StoragePolicy > &val);
+RcppHoney::traits::true_type needs_scalar_operators(
+    const Rcpp::Matrix< RTYPE, StoragePolicy > &val);
 
 // call this family 3
 template< int RTYPE, template< class > class StoragePolicy >
-RcppHoney::traits::int_constant< 3 > family(const Rcpp::Matrix< RTYPE, StoragePolicy > &val);
+RcppHoney::traits::int_constant< 3 > family(
+    const Rcpp::Matrix< RTYPE, StoragePolicy > &val);
 
 template< int RTYPE, template< class > class StoragePolicy >
 dims_t extract_dims(
